@@ -1,11 +1,11 @@
-pub fn to_string(p1: &[crate::p1::Section]) -> String {
+pub fn to_string(p1: &[ftd::p1::Section]) -> String {
     p1.iter()
         .map(|v| v.to_string().trim().to_string())
         .collect::<Vec<String>>()
         .join("\n\n\n")
 }
 
-impl std::fmt::Display for crate::p1::Section {
+impl std::fmt::Display for ftd::p1::Section {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         if self.is_commented {
             write!(f, "/-- {}:", self.name.as_str())?;
@@ -34,7 +34,7 @@ impl std::fmt::Display for crate::p1::Section {
     }
 }
 
-impl std::fmt::Display for crate::p1::SubSection {
+impl std::fmt::Display for ftd::p1::SubSection {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         if self.is_commented {
             write!(f, "/--- {}:", self.name.as_str())?;
@@ -189,18 +189,18 @@ mod test {
             bar body"
             ),
             super::to_string(&vec![
-                crate::p1::Section::with_name("foo")
+                ftd::p1::Section::with_name("foo")
                     .and_body("body ho")
                     .add_header("key", "value")
                     .add_sub_section(
-                        crate::p1::SubSection::with_name("dodo")
+                        ftd::p1::SubSection::with_name("dodo")
                             .and_caption("foo")
                             .add_header("foo", "bar"),
                     )
                     .add_sub_section(
-                        crate::p1::SubSection::with_name("dodo").add_header("foo", "bar")
+                        ftd::p1::SubSection::with_name("dodo").add_header("foo", "bar")
                     ),
-                crate::p1::Section::with_name("bar").and_body("bar body")
+                ftd::p1::Section::with_name("bar").and_body("bar body")
             ]),
         );
 
@@ -213,7 +213,7 @@ mod test {
             body ho"
             ),
             super::to_string(&vec![
-                crate::p1::Section::with_name("foo").and_body("-- yo:\nbody ho")
+                ftd::p1::Section::with_name("foo").and_body("-- yo:\nbody ho")
             ]),
         );
 
@@ -224,8 +224,8 @@ mod test {
 
             --- bar:"
             ),
-            super::to_string(&vec![crate::p1::Section::with_name("foo")
-                .add_sub_section(crate::p1::SubSection::with_name("bar")),]),
+            super::to_string(&vec![ftd::p1::Section::with_name("foo")
+                .add_sub_section(ftd::p1::SubSection::with_name("bar")),]),
         );
     }
 }
